==> nextcloud-app-tasks-0.13.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ko.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "중요",
    "Today" : "오늘",
    "Week" : "주",
    "All" : "모두",
    "Current" : "현재",
    "Completed" : "완료됨",
    "Tasks" : "작업",
    "Share with users or groups" : "사용자 및 그룹과 공유",
    "No users or groups" : "사용자나 그룹 없음",
    "can edit" : "편집 가능",
    "Unable to delete the share." : "이 공유를 삭제할 수 없습니다.",
    "Unable to change permissions." : "권한을 변경할 수 없습니다.",
    "New List" : "새 목록",
    "Cancel" : "취소",
    "Save" : "저장",
    "An empty name is not allowed." : "이름을 비워둘 수 없습니다.",
    "Edit" : "편집",
    "Copy private link" : "개인 링크 주소 복사",
    "Copied" : "복사됨",
    "Can not copy" : "복사할 수 없음",
    "Download" : "다운로드",
    "Delete" : "삭제",
    "Unshare" : "공유 해제",
    "Calendar link copied to clipboard." : "일정의 링크를 클립보드에 복사되었습니다.",
    "Calendar link could not be copied to clipboard." : "일정의 링크를 클립보드에 저장할 수 없습니다.",
    "An error occurred, unable to delete the calendar." : "오류가 발생하여 일정을 삭제할 수 없습니다.",
    "Visibility of Smart Collections" : "똑똑한 모음집 표시 여부",
    "Hidden" : "숨김",
    "Visible" : "보임",
    "Automatic" : "자동",
    "No errors" : "오류 없음",
    "Open your browser console for more details" : "자세한 정보를 보려면 브라우저 콘솔을 여십시오",
    "Change sort order" : "정렬 순서 변경",
    "Start date" : "시작 날짜",
    "Due date" : "마감 날짜",
    "Last modified" : "수정한 날짜",
    "Priority" : "우선 순위",
    "Alphabetically" : "가나다순",
    "Manually" : "수동으로",
    "Task is completed" : "작업이 완료됨",
    "_%n Completed Task_::_%n Completed Tasks_" : ["완료된 작업 %n개"],
    "Tomorrow" : "내일",
    "Set start date" : "시작 날짜 지점",
    "Set due date" : "만료 기한 설정",
    "All day" : "하루 종일",
    "Task not found!" : "작업을 찾을 수 없습니다!",
    "When shared show full event" : "전체 일정 공유",
    "When shared show only busy" : "바쁨/한가함만 공유",
    "When shared hide this event" : "일정 공유하지 않음",
    "An error occurred" : "오류가 발생함"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.13.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ko.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "중요",
    "Today" : "오늘",
    "Week" : "주",
    "All" : "모두",
    "Current" : "현재",
    "Completed" : "완료됨",
    "Tasks" : "작업",
    "Add List…" : "리스트 더하기...",
    "New List" : "새 목록",
    "Cancel" : "취소",
    "Save" : "저장",
    "An empty name is not allowed." : "이름을 비워둘 수 없습니다.",
    "Share with users or groups" : "사용자 및 그룹과 공유",
    "No users or groups" : "사용자나 그룹 없음",
    "can edit" : "편집 가능",
    "Unable to delete the share." : "이 공유를 삭제할 수 없습니다.",
    "Unable to change permissions." : "권한을 변경할 수 없습니다.",
    "Edit" : "편집",
    "Copy private link" : "개인 링크 주소 복사",
    "Copied" : "복사됨",
    "Can not copy" : "복사할 수 없음",
    "Download" : "다운로드",
    "Delete" : "삭제",
    "Unshare" : "공유 해제",
    "Calendar link copied to clipboard." : "일정의 링크를 클립보드에 복사되었습니다.",
    "Calendar link could not be copied to clipboard." : "일정의 링크를 클립보드에 저장할 수 없습니다.",
    "An error occurred, unable to delete the calendar." : "오류가 발생하여 일정을 삭제할 수 없습니다.",
    "Default list" : "기본 리스트",
    "Visibility of Smart Collections" : "똑똑한 모음집 표시 여부",
    "Hidden" : "숨김",
    "Visible" : "보임",
    "Automatic" : "자동",
    "Delete all completed tasks." : "모든 완료된 일 지우기",
    "Delete completed tasks." : "완료된 일 지우기",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "\"{calendar}\" 달력의 모든 완료된 일 지우기",
    "No errors" : "오류 없음",
    "Open your browser console for more details" : "자세한 정보를 보려면 브라우저 콘솔을 여십시오",
    "Load all completed tasks." : "완료된 일 불러오기",
    "Change sort order" : "정렬 순서 변경",
    "Start date" : "시작 날짜",
    "Sort by start date and summary." : "시작일과 요약으로 정렬",
    "Due date" : "마감 날짜",
    "Sort by due date and summary." : "기한과 요약으로 정렬",
    "Created date" : "생성된 날짜",
    "Sort by created date and summary." : "생성일자와 요약으로 정렬",
    "Last modified" : "수정한 날짜",
    "Sort by last-modified date and summary." : "최종 수정일과 요약으로 정렬",
    "Completed date" : "완료된 날짜",
    "Sort by completed date." : "완료된 날짜로 정렬",
    "Priority" : "우선 순위",
    "Sort by priority and summary." : "우선순위와 요약으로 정렬",
    "Alphabetically" : "가나다순",
    "Manually" : "수동으로",
    "Task is completed" : "작업이 완료됨",
    "_%n Completed Task_::_%n Completed Tasks_" : ["완료된 작업 %n개"],
    "Tomorrow" : "내일",
    "Set start date" : "시작 날짜 지점",
    "Set due date" : "만료 기한 설정",
    "All day" : "하루 종일",
    "Task not found!" : "작업을 찾을 수 없습니다!",
    "When shared show full event" : "전체 일정 공유",
    "When shared show only busy" : "바쁨/한가함만 공유",
    "When shared hide this event" : "일정 공유하지 않음",
    "Canceled" : "취소됨",
    "An error occurred" : "오류가 발생함"
},
"nplurals=1; plural=0;");
